==> generator-jhipster-micronaut-3.0.0.tgz: package/generators/liquibase/generator.js <==
import BaseApplicationGenerator from 'generator-jhipster/generators/base-application';
import constants from '../constants.cjs';

export default class extends BaseApplicationGenerator {
  constructor(args, opts, features) {
    super(args, opts, { ...features, sbsBlueprint: true });
  }

  get [BaseApplicationGenerator.POST_WRITING]() {
    return this.asPostWritingTaskGroup({
      micronautLiquibase({ application, source }) {
        if (application.buildToolMaven) {
          source.addMavenDefinition?.({
            properties: [{ property: 'liquibase-hibernate6.version', value: constants.versions.liquibaseHibernate6 }],
            dependencies: [
              {
                groupId: 'io.micronaut.liquibase',
                artifactId: 'micronaut-liquibase',
                scope: 'compile',
              },
              {
                groupId: 'org.liquibase.ext',
                artifactId: 'liquibase-hibernate6',
                version: '${liquibase-hibernate6.version}',
                scope: 'runtime',
              },
            ],
            plugins: [
              {
                groupId: 'org.liquibase',
                artifactId: 'liquibase-maven-plugin',
                version: '${liquibase.version}',
              },
            ],
          });
        } else if (application.buildToolGradle) {
          source.addGradleDependency?.({
            groupId: 'io.micronaut.liquibase',
            artifactId: 'micronaut-liquibase',
            scope: 'implementation',
          });
        }
      },
    });
  }
}

==> generator-jhipster-micronaut-3.2.0.tgz: package/generators/liquibase/generator.js <==
import BaseApplicationGenerator from 'generator-jhipster/generators/base-application';

export default class extends BaseApplicationGenerator {
  constructor(args, opts, features) {
    super(args, opts, { ...features, sbsBlueprint: true });
  }

  get [BaseApplicationGenerator.POST_WRITING]() {
    return this.asPostWritingTaskGroup({
      micronautLiquibase({ application, source }) {
        if (application.buildToolMaven) {
          source.addMavenDefinition?.({
            properties: [{ property: 'liquibase.version', value: application.javaDependencies.liquibase }],
            dependencies: [
              {
                groupId: 'io.micronaut.liquibase',
                artifactId: 'micronaut-liquibase',
                scope: 'compile',
              },
              {
                groupId: 'org.liquibase.ext',
                artifactId: 'liquibase-hibernate6',
                scope: 'runtime',
                exclusions: {
                  exclusion: {
                    groupId: 'org.slf4j',
                    artifactId: 'slf4j-simple',
                  },
                },
              },
            ],
            dependencyManagement: [
              {
                groupId: 'org.liquibase.ext',
                artifactId: 'liquibase-hibernate6',
                version: '${liquibase.version}',
              },
            ],
            plugins: [
              {
                groupId: 'org.liquibase',
                artifactId: 'liquibase-maven-plugin',
                version: '${liquibase.version}',
              },
            ],
          });
        } else if (application.buildToolGradle) {
          source.addGradleDependency?.({
            groupId: 'io.micronaut.liquibase',
            artifactId: 'micronaut-liquibase',
            scope: 'implementation',
          });
        }
      },
    });
  }
}
